import pathlib
import unittest

import clishelf.utils as utils


class UtilsTestCase(unittest.TestCase):
    def test_pwd(self):
        result = utils.pwd()
        self.assertEqual(pathlib.Path("."), result)

    def test_make_color(self):
        result = utils.make_color("test", utils.Level.OK)
        self.assertEqual("\x1b[92m\x1b[1mOK: test\x1b[0m", result)



import unittest

import clishelf.settings as settings


class SettingsTestCase(unittest.TestCase):
    def test_bump_version_update_dt_pre(self):
        result = settings.BumpVerConf.update_dt_pre("20230101")
        self.assertEqual("20230101.1", result)

        result = settings.BumpVerConf.update_dt_pre("20230101.99")
        self.assertEqual("20230101.100", result)



import unittest

from click.testing import CliRunner

from clishelf.cli import echo


class CliTestCase(unittest.TestCase):
    def test_hello_world(self):
        runner = CliRunner()
        result = runner.invoke(echo)
        self.assertEqual(0, result.exit_code)
        self.assertEqual("Hello World\n", result.output)
